import { ViewPlugin, ViewUpdate } from "@codemirror/view";
import { Facet, StateField, EditorState } from "@codemirror/state";
/**
 * The inner method to fetch suggestions: this is
 * abstracted by `inlineCopilot`.
 */
type InlineFetchFn = (state: EditorState) => Promise<string>;
export declare const suggestionConfigFacet: Facet<{
    acceptOnClick: boolean;
    fetchFn: InlineFetchFn;
}, {
    acceptOnClick: boolean;
    fetchFn: InlineFetchFn | undefined;
}>;
/**
 * Listens to document updates and calls `fetchFn`
 * to fetch auto-suggestions. This relies on
 * `InlineSuggestionState` also being installed
 * in the editor’s extensions.
 */
export declare const fetchSuggestion: ViewPlugin<{
    cancelSuggestion: boolean;
    update(update: ViewUpdate): Promise<void>;
}>;
/**
 * Options to configure the AI suggestion UI.
 */
type InlineSuggestionOptions = {
    fetchFn: InlineFetchFn;
    /**
     * Delay after typing to query the API. A shorter
     * delay will query more often, and cost more.
     */
    delay?: number;
    /**
     * Whether clicking the suggestion will
     * automatically accept it.
     */
    acceptOnClick?: boolean;
};
/**
 * Configure the UI, state, and keymap to power
 * auto suggestions.
 */
export declare function inlineSuggestion(options: InlineSuggestionOptions): (StateField<{
    suggestion: string | null;
}> | import("@codemirror/state").Extension)[];
export {};
